import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manages people's membership to GitHub teams
 *
 * @schema CfnMembershipProps
 */
export interface CfnMembershipProps {
    /**
     * The organization name. The name is not case sensitive. If not specified, then the managed repository will be within the currently logged-in user account.
     *
     * @schema CfnMembershipProps#Org
     */
    readonly org: string;
    /**
     * TThe slug of the team name.
     *
     * @schema CfnMembershipProps#TeamSlug
     */
    readonly teamSlug: string;
    /**
     * The handle for the GitHub user account.
     *
     * @schema CfnMembershipProps#Username
     */
    readonly username?: string;
    /**
     * The handle for the GitHub user account.
     *
     * @schema CfnMembershipProps#Role
     */
    readonly role?: CfnMembershipPropsRole;
}
/**
 * Converts an object of type 'CfnMembershipProps' to JSON representation.
 */
export declare function toJson_CfnMembershipProps(obj: CfnMembershipProps | undefined): Record<string, any> | undefined;
/**
 * The handle for the GitHub user account.
 *
 * @schema CfnMembershipPropsRole
 */
export declare enum CfnMembershipPropsRole {
    /** member */
    MEMBER = "member",
    /** maintainer */
    MAINTAINER = "maintainer"
}
/**
 * A CloudFormation `GitHub::Teams::Membership`
 *
 * @cloudformationResource GitHub::Teams::Membership
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-github-resource-providers.git
 */
export declare class CfnMembership extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "GitHub::Teams::Membership";
    /**
     * Resource props.
     */
    readonly props: CfnMembershipProps;
    /**
     * Attribute `GitHub::Teams::Membership.State`
     * @link https://github.com/aws-ia/cloudformation-github-resource-providers.git
     */
    readonly attrState: string;
    /**
     * Create a new `GitHub::Teams::Membership`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnMembershipProps);
}
